@@ -5,7 +5,7 @@ actual BOOLEAN DEFAULT false, -- is this the actual version?
 version_major INT NOT NULL,
 version_minor INT NOT NULL,
 version_patchlevel INT NOT NULL,
-version_string VARCHAR(16) DEFAULT NULL,
+version_string VARCHAR(32) DEFAULT NULL,
 description TEXT DEFAULT NULL, -- information to be dislayed to the user
 major BOOLEAN DEFAULT false, -- whether this version was major
 beta BOOLEAN DEFAULT false, -- is this a beta version
@@ -302,6 +302,7 @@ cert_token VARCHAR(32) DEFAULT NULL,
 deleted BOOLEAN DEFAULT false, -- flag to set if device deleted during runtime. Device is purged from DB on next daemon startup
 name VARCHAR(32) DEFAULT NULL, -- custom name for a device
 dev_type INT,
+snmp_subdevtype INT DEFAULT NULL, -- device type guessed out of SNMP data
 os_ver INT,
 os_ver_desired INT,
 macaddr VARCHAR(12) DEFAULT NULL,
@@ -323,6 +324,7 @@ agent_profile INT DEFAULT 1,
 ignore_alldev_alerts BOOLEAN DEFAULT FALSE,
 machine_id VARCHAR(180),
 FOREIGN KEY (dev_type) REFERENCES device_types(id),
+FOREIGN KEY (snmp_subdevtype) REFERENCES device_types(id),
 FOREIGN KEY (os_ver) REFERENCES device_os_versions(id),
 FOREIGN KEY (os_ver_desired) REFERENCES device_os_versions(id),
 FOREIGN KEY (config_profile) REFERENCES config_profiles(id),
@@ -1017,12 +1019,7 @@ FOREIGN KEY (atom) REFERENCES data_atom(id),
 FOREIGN KEY (id_device) REFERENCES devices(id_device) ON DELETE CASCADE
 );
 
-CREATE TRIGGER delban_6_dcl
-BEFORE DELETE ON data_change_log
-FOR EACH ROW
-SIGNAL SQLSTATE '45000' SET MESSAGE_TEXT = 'Delete not allowed on simpletable';
-
-CREATE TRIGGER delban_7_device_models
+CREATE TRIGGER delban_8_device_models
 BEFORE DELETE ON device_models
 FOR EACH ROW
 SIGNAL SQLSTATE '45000' SET MESSAGE_TEXT = 'Delete not allowed on simpletable';
