@@ -10,14 +10,15 @@ INSERT INTO agents (name, dir_name, package_name, minimal_version, dev_type, sho
 INSERT INTO agent_device_type_map (agent_id, device_type_id) VALUES (1, 2), (2, 1), (3, 3), (4, 4), (1, 5);
 
 INSERT INTO agent_versions (dev_type, version_major, version_minor, version_patchlevel, actual) VALUES
-(1, 1, 0, 0, true),
-(2, 1, 0, 0, true),
-(3, 1, 0, 0, true),
-(4, 1, 0, 0, true);
+(1, 1, 1, 0, true),
+(2, 1, 1, 0, true),
+(3, 1, 1, 0, true),
+(4, 1, 1, 0, true);
 
 INSERT INTO product_versions (id, actual, version_major, version_minor, version_patchlevel, version_string, major, beta, notification, force_display, release_date, description) values 
-(1, true, 1, 1, 0, 'Afterparty', false, true, true, true, NOW(),
+(1, true, 1, 2, 0, 'Afterparty 2 (Keeper BETA 2)', false, true, true, true, '2025-09-30',
 '<h5>Release notes</h5>'
+'<b>The release notes below are not completely relevant to the BETA version you are running, these are preparations for the Dwarfguard 2.0.0 Keeper version.</b>'
 '<h6>Server:</h6><ul>'
 '<li>Support for manual upload of firmware files by user + logging for this action.</li>'
 '<li>Support firmware management for Teltonika devices (running RUTOS).</li>'
@@ -36,7 +37,7 @@ INSERT INTO product_versions (id, actual, version_major, version_minor, version_
 '<li>List of triggered devices can now be accessed directly from alert definition table.</li>'
 '<li>Improvements in UI - horizontal scrolling, ordering fix</li>'
 '<li>Updated Symfony.</li>'
-'<li>Incorporated all fixes from stable support releases 1.0.1 - 1.0.3</li>'
+'<li>Incorporated all fixes from stable support releases 1.0.1 - 1.0.4</li>'
 '<li></li>'
 '</ul><h6>Agents:</h6><ul>'
 '<li>Support for CSTECH devices (enhanced Advatech agent to cover both Advantech and CSTECH devices)</li>'
@@ -49,14 +50,14 @@ INSERT INTO product_versions (id, actual, version_major, version_minor, version_
 '<li></li>'
 '</ul>');
 
-INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.0.3 (+305)');
+INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.0.4 (+339)');
 INSERT INTO product_flags(id, version, description) values ('about_info', 1, 'Dwarfguard - Monitoring, Alerting, Management and Automation System
 
-Build tag: v1.0.3 (+305)
-Build date: 2025_09_14__09_29_27
+Build tag: v1.0.4 (+339)
+Build date: 2025_09_30__14_43_01
 
 Build components:
-(mamas): v1.0.3 (+196)
-(mamasbig): v1.0.3 (+8)
-(mamasweb): v1.0.3 (+101)
-(mamasnotify): v1.0.3');
+(mamas): v1.0.4 (+216)
+(mamasbig): v1.0.4 (+9)
+(mamasweb): v1.0.4 (+114)
+(mamasnotify): v1.0.4');
