@@ -27,7 +27,7 @@ from datetime import datetime
 warnings.filterwarnings('ignore')
 
 appname="Dwarfguard SNMP Gateway"
-appversion="0.2.1"
+appversion="0.3.0"
 agent_version="1.1.0"
 
 # knobs (defaults)
@@ -163,8 +163,11 @@ def talk(string, mloglevel = logging.DEBUG, logger = None):
     else:
         logger.log(mloglevel, string)
 
-def checkadv(string):
-    return string
+# ------ HELPERS --------
+def checktype(string):
+    if string is not None and string.startswith("1.3.6.1.4.1.30140"):
+        return 2
+    return 6
 
 def uptime(u):
     return str(u.total_seconds())
@@ -172,13 +175,22 @@ def uptime(u):
 def voltage(v):
     return str('{:.2f}'.format(v/1000))+" V"
 
+def activesim(s):
+    if isinstance(s, int):
+        if 2 == int(s):
+            return "3rd"
+        if 1 == int(s):
+            return "2nd"
+    return "1st"
+
 def quote(string):
     return '"'+str(string)+'"'
 
 fdict = {
-        'c': checkadv,
+        'c': checktype,
         'u': uptime,
         'v': voltage,
+        's': activesim,
         '"': quote
         }
 
@@ -190,7 +202,7 @@ def get_func(string):
 oids_advantech = [
         # OID, section, subsection, prefix, number, helpers
         ( "1.3.6.1.2.1.1.1", None, None, None, False, None),  # SysDescr
-        ( "1.3.6.1.2.1.1.2", None, None, None, False, "c"), # prodtype (must be 1.3.6.1.4.1.30140.* for advantech)
+        ( "1.3.6.1.2.1.1.2", "STAT", "various", "snmphint=", True, "c"), # prodtype (must be 1.3.6.1.4.1.30140.* for advantech)
         ( "1.3.6.1.2.1.1.3", "STAT", "various", "uptime=", False, 'u"'),  # sysUpTime (/100 seconds)
         ( "1.3.6.1.2.1.1.5", "STAT", "various", "snmpname=", False, '"'),        # SysName
         ( "1.3.6.1.4.1.30140.3.3", "STAT", "status sys", "Temperature     : ", True, None),  # temperature
@@ -199,10 +211,11 @@ oids_advantech = [
         ( "1.3.6.1.4.1.30140.3.9", "STAT", "various", "memavail=", True, None),  # RAM free (bytes)
         ( "1.3.6.1.4.1.30140.3.10", "STAT", "various", "memtotal=", True, None), # RAM total (bytes)
         ( "1.3.6.1.4.1.30140.4.5", "STAT", "status mobile", "Signal Strength : ", True, None), # Signal strength for cell (dBm)
-        ( "1.3.6.1.4.1.30140.4.19", "STAT", "status mwan", "SIM Card      : ", True, None),  # SIM card selected
+        ( "1.3.6.1.4.1.30140.4.19", "STAT", "status mwan", "SIM Card      : ", False, 's'),  # SIM card selected
         ( "1.3.6.1.4.1.30140.4.20", "STAT", "status mwan", "IP Address    : ", False, None), # mobile IP
         ( "1.3.6.1.4.1.30140.4.26", "STAT", "status mobile", "Signal Quality : ", True, None), # Signal quality of a cell
         ( "1.3.6.1.4.1.30140.4.27", "STAT", "status mobile", "CSQ : ", True, None), # Signal strength (CSQ)
+        ( "1.3.6.1.4.1.30140.4.30", "STAT", "status mobile", "RSSI : ", True, None), # Signal strength (RSSI)
         ( "1.3.6.1.4.1.30140.6.1", "STAT", "status sys", "Product Name     : ", False, None), # Product
         ( "1.3.6.1.4.1.30140.6.2", "STAT", "status sys", "Firmware Version : ", False, None), # Firmware version
         ( "1.3.6.1.4.1.30140.6.3", "STAT", "status sys", "Serial Number    : ", False, None), # Serial NO
