@@ -289,6 +289,25 @@ abstract class AbstractDatatable implements DatatableInterface
         return $options;
     }
 
+	public function getOptionsArrayFromEntitiesWithNeg(array $entities, string $keyFrom = 'id', string $valueFrom = 'name'): array
+	{
+		$options = [];
+
+		foreach ($entities as $entity) {
+			if (true === $this->accessor->isReadable($entity, $keyFrom) && true === $this->accessor->isReadable($entity, $valueFrom)) {
+				$options[$this->accessor->getValue($entity, $keyFrom)] = $this->accessor->getValue($entity, $valueFrom);
+			}
+		}
+
+		foreach ($entities as $entity) {
+			if (true === $this->accessor->isReadable($entity, $keyFrom) && true === $this->accessor->isReadable($entity, $valueFrom)) {
+				$options['!'.$this->accessor->getValue($entity, $keyFrom)] = 'Not ' . $this->accessor->getValue($entity, $valueFrom);
+			}
+		}
+
+		return $options;
+	}
+
     /**
      * {@inheritdoc}
      */
