@@ -128,10 +128,16 @@ class SettingsController extends Controller {
             }
         }
 
+		$configNames = [];
+		//Get group builder which is part of the form named 'config'
+		foreach ($settingsForm->all()['config'] as $item){
+			//Used to generate js to disable and enable items in the form
+			$configNames[] = $item->getName();
+		}
+
         return $this->render('system/settings.html.twig', [
             'settingsForm' => $settingsForm->createView(),
-            //Get group builder which is part of the form named 'config'
-            'configItems' => $settingsForm->all()['config'] ?? null,
+            'configNames' => $configNames ?? null,
             'nonWritableConfigData' => $this->getNonWritableConfigData($configFormData),
             'deviceTableColumnsChoices' => $deviceTableColumnsChoices,
         ]);
