@@ -33,7 +33,7 @@ class DeviceDatatable extends BaseDatatable
     public const showColumns = ['devId', 'name', 'devTypeName', 'OsVerOsTypeName', 'OsVerVersion', 'Labels',
                         'MonitoringGroups', 'StatsSyncStatusDescription', 'StatLiveMissCountDescription'];
 
-    public const availableColumns = ['devId' => 'DevId', 'name' => 'Name', 'devTypeName' => 'Type',
+    public const availableColumns = ['devId' => 'DevId', 'name' => 'Name', 'devTypeName' => 'Type', 'SnpmDevTypeName' => 'SNMP subtype',
         'OsVerOsTypeName' => "OS", 'OsVerVersion' => 'Version', 'Labels' => 'Labels', 'SystemLabels' => 'System Labels',
         'IpAddresses' => 'Ip Addresses', 'MonitoringGroups' => 'MonitoringGroups',
         'ConfigProfileAutomaticDevId' => 'Cloned From', 'StatsSyncStatusDescription' => 'Sync Status',
@@ -41,6 +41,7 @@ class DeviceDatatable extends BaseDatatable
         'MacAddress' => 'Mac Address', self::tableColumnName_SnmpName => self::username_SnmpName,
         'Model' => 'Model', 'HostName' => 'Host Name', 'Uuid' => 'UuId',
         'Iccid' => 'IccId', 'ActiveSim' => 'Active Sim', 'SignalStrength' => 'Signal Strength', 'SignalQuality' => 'Signal Quality',
+		'SignalCsq' => 'Signal CSQ', 'SignalRssi' => 'Signal RSSI',
         'Temperature' => 'Temperature', 'AgentProfile' => 'Agent Profile', 'AuthProfile' => 'Auth Profile',
 		'simIpaddr' => 'SIM IPv4', 'simIp6addr' => 'SIM IPv6',
         'Note1' => 'Note 1', 'Note2' => 'Note 2', 'Note3' => 'Note 3',
@@ -535,6 +536,11 @@ class DeviceDatatable extends BaseDatatable
         $this->addDefaultSelectableFilterColumns('devType.name', 'Type', $this->getOptionsArrayFromEntities($this->deviceTypes, 'name', 'name'));
     }
 
+	private function getColumnSnpmDevTypeName(): void
+	{
+		$this->addDefaultSelectableFilterColumns('snmpSubDevType.name', 'SNMP subtype', $this->getOptionsArrayFromEntities($this->deviceTypes, 'name', 'name'));
+	}
+
     private function getColumnOsVerOsTypeName(): void
     {
         $this->addDefaultSelectableFilterColumns('osVer.osType.name', 'OS', $this->getOptionsArrayFromEntities($this->osTypes, 'name', 'name'));
@@ -555,8 +561,8 @@ class DeviceDatatable extends BaseDatatable
                 'name' => 'labels',
                 'title' => 'Labels',
                 'width' => '100%;',
-                'dql' => "(SELECT GROUP_CONCAT({l}.label) FROM App:Label\LabelDeviceMap {p}
-                                JOIN App:Label\Label {l} with {l}.id = {p}.labelId
+                'dql' => "(SELECT GROUP_CONCAT({l}.label) FROM App\Entity\Label\LabelDeviceMap {p}
+                                JOIN App\Entity\Label\Label {l} with {l}.id = {p}.labelId
                                 WHERE {p}.device = vdevice )",
                 'type_of_field' => 'integer',
                 'searchable' => true,
@@ -630,8 +636,8 @@ class DeviceDatatable extends BaseDatatable
                 'name' => 'systemLabels',
                 'title' => 'System Labels',
                 'width' => '100%;',
-                'dql' => "(SELECT GROUP_CONCAT({sl}.label) FROM App:Label\SystemLabelDeviceMap {pa}
-                                JOIN App:Label\SystemLabel {sl} with {sl}.id = {pa}.labelId
+                'dql' => "(SELECT GROUP_CONCAT({sl}.label) FROM App\Entity\Label\SystemLabelDeviceMap {pa}
+                                JOIN App\Entity\Label\SystemLabel {sl} with {sl}.id = {pa}.labelId
                                 WHERE {pa}.device = vdevice )",
                 'type_of_field' => 'integer',
                 'searchable' => true,
@@ -713,17 +719,17 @@ class DeviceDatatable extends BaseDatatable
 
     private function getColumnNumber(int $numberNum): void
     {
-        $this->addDefaultTextColumn('customFieldDevice.number' . $numberNum, 'Number ' . $numberNum, '');
+        $this->addDefaultTextColumn('customFieldDevice.number' . $numberNum, 'Number ' . $numberNum);
     }
 
     private function getColumnFloat(int $numberNum): void
     {
-        $this->addDefaultTextColumn('customFieldDevice.float' . $numberNum, 'Float ' . $numberNum, '');
+        $this->addDefaultTextColumn('customFieldDevice.float' . $numberNum, 'Float ' . $numberNum);
     }
 
     private function getColumnText(int $numberNum): void
     {
-        $this->addDefaultTextColumn('customFieldDevice.text' . $numberNum, 'Text ' . $numberNum, '');
+        $this->addDefaultTextColumn('customFieldDevice.text' . $numberNum, 'Text ' . $numberNum);
     }
 
     private function getColumnMonitoringGroups(): void
@@ -737,8 +743,8 @@ class DeviceDatatable extends BaseDatatable
                 'name' => 'monitoringGroups',
                 'title' => 'Monitoring Groups',
                 'width' => '100%;',
-                'dql' => "(SELECT GROUP_CONCAT(CONCAT_WS('_', {mg}.id, {mg}.name)) FROM App:MonitoringGroup\MonitoringGroupMapping {mgmapping}
-                                JOIN App:MonitoringGroup\MonitoringGroup {mg} with {mg}.id = {mgmapping}.monitoringGroup
+                'dql' => "(SELECT GROUP_CONCAT(CONCAT_WS('_', {mg}.id, {mg}.name)) FROM App\Entity\MonitoringGroup\MonitoringGroupMapping {mgmapping}
+                                JOIN App\Entity\MonitoringGroup\MonitoringGroup {mg} with {mg}.id = {mgmapping}.monitoringGroup
                                 WHERE {mgmapping}.device = vdevice )",
                 'type_of_field' => 'integer',
                 'searchable' => true,
@@ -758,7 +764,7 @@ class DeviceDatatable extends BaseDatatable
 
     private function getColumnMacAddress(): void
     {
-        $this->addDefaultTextColumn('macAddr', 'MAC', '');
+        $this->addDefaultTextColumn('macAddr', 'MAC');
     }
 
     private function getColumnSerialNumber(): void
@@ -778,12 +784,12 @@ class DeviceDatatable extends BaseDatatable
 
     private function getColumnSnmpname(): void
     {
-        $this->addDefaultTextColumn(self::tableColumnName_SnmpName, self::username_SnmpName, '');
+        $this->addDefaultTextColumn(self::tableColumnName_SnmpName, self::username_SnmpName);
     }
 
     private function getColumnUuid(): void
     {
-        $this->addDefaultTextColumn('uuid', 'UUID', '');
+        $this->addDefaultTextColumn('uuid', 'UUID');
     }
 
     private function getColumnIccid(): void
@@ -821,27 +827,37 @@ class DeviceDatatable extends BaseDatatable
 
     private function getColumnSignalStrength(): void
     {
-        $this->addDefaultTextColumn('stats.signalStrength', 'Signal signalStrength', '');
+        $this->addDefaultTextColumn('stats.signalStrength', 'Signal signalStrength');
     }
 
     private function getColumnSignalQuality()
     {
-        $this->addDefaultTextColumn('stats.signalQuality', 'Signal Quality', '');
+        $this->addDefaultTextColumn('stats.signalQuality', 'Signal Quality');
     }
 
+	private function getColumnSignalCsq()
+    {
+        $this->addDefaultTextColumn('stats.signalCsq', 'Signal CSQ');
+    }
+
+	private function getColumnSignalRssi()
+	{
+		$this->addDefaultTextColumn('stats.signalRssi', 'Signal RSSI');
+	}
+
     private function getColumnTemperature(): void
     {
-        $this->addDefaultTextColumn('stats.temperature', 'Temperature', '');
+        $this->addDefaultTextColumn('stats.temperature', 'Temperature');
     }
 
 	private function getColumnSimIpaddr(): void
 	{
-		$this->addDefaultTextColumn('stats.simIpaddr', 'SIM IPv4', '');
+		$this->addDefaultTextColumn('stats.simIpaddr', 'SIM IPv4');
 	}
 
 	private function getColumnSimIp6addr(): void
 	{
-		$this->addDefaultTextColumn('stats.simIp6addr', 'SIM IPv6', '');
+		$this->addDefaultTextColumn('stats.simIp6addr', 'SIM IPv6');
 	}
 
     private function getColumnConfigProfileAutomaticDevId(): void
@@ -928,7 +944,7 @@ class DeviceDatatable extends BaseDatatable
     /**
      * @throws \Exception
      */
-    private function addDefaultTextColumn(string $dqlColumn, string $title, string $defaultContentValue = 'None'): void
+    private function addDefaultTextColumn(string $dqlColumn, string $title, string $defaultContentValue = ''): void
     {
 
         $this->columnBuilder->add(
