@@ -2,7 +2,7 @@
 
 namespace App\Form\Device;
 
-use App\Entity\Device;
+use App\Entity\Device\Device;
 use Symfony\Component\Form\AbstractType;
 use Symfony\Component\Form\Extension\Core\Type\HiddenType;
 use Symfony\Component\Form\Extension\Core\Type\SubmitType;
@@ -10,12 +10,12 @@ use Symfony\Component\Form\FormBuilderInterface;
 
 class DeviceCustomModuleDownloadType extends AbstractType
 {
-
     /**
      * @param FormBuilderInterface $builder
      * @param array $options
      */
-    public function buildForm(FormBuilderInterface $builder, array $options){
+    public function buildForm(FormBuilderInterface $builder, array $options): void
+    {
 
         /** @var Device $device */
         $device = $options['data']['device'];
@@ -32,7 +32,5 @@ class DeviceCustomModuleDownloadType extends AbstractType
                 'label_html' => true,
                 'attr' => ['class' => 'btn-primary btn-xs']])
         ;
-
     }
-
-}
\ No newline at end of file
+}
