@@ -2,7 +2,7 @@
 
 namespace App\Repository;
 
-use App\Entity\TypesValueType;
+use App\Entity\Types\TypesValueType;
 use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
 use Doctrine\Persistence\ManagerRegistry;
 
